Intents

Struct Intents 

pub struct Intents(/* private fields */);
Gateway intents.

Developers must specify intents when connecting to the gateway. The intents specified correspond with the events received. To specify multiple intents, create a union using the | operator. See Discord Docs/Gateway Intents.

Implementations

Source

impl Intents

pub const GUILDS: Intents

pub const GUILD_MEMBERS: Intents

Guild members intent.

This intent is privileged. See Discord Docs/Privileged Intents.

Event(s) received:

pub const GUILD_MODERATION: Intents

Guild moderation intent.

Event(s) received:

pub const GUILD_EMOJIS_AND_STICKERS: Intents

Guild emojis and stickers intent.

Event(s) received:

pub const GUILD_INTEGRATIONS: Intents

pub const GUILD_WEBHOOKS: Intents

Guild webhooks intent.

Event(s) received:

pub const GUILD_INVITES: Intents

Guild invites intent.

Event(s) received:

pub const GUILD_VOICE_STATES: Intents

Guild voice states intent.

Event(s) received:

pub const GUILD_PRESENCES: Intents

Guild presences intent.

This intent is privileged. See Discord Docs/Privileged Intents.

Event(s) received:

pub const GUILD_MESSAGES: Intents

Guild messages intent.

Event(s) received:

pub const GUILD_MESSAGE_REACTIONS: Intents

pub const GUILD_MESSAGE_TYPING: Intents

Guild message typing intent.

Event(s) received:

pub const DIRECT_MESSAGES: Intents

Direct messages intent.

Event(s) received:

This is different from the GUILD_MESSAGES intent in that the bot will receive message events from locations other than guilds.

pub const DIRECT_MESSAGE_REACTIONS: Intents

Direct message reactions intent.

Event(s) received:

This is different from the GUILD_MESSAGE_REACTIONS event in that the bot will receive message reaction events from locations other than guilds.

pub const DIRECT_MESSAGE_TYPING: Intents

Direct message typing intent.

Event(s) received:

This is different from the GUILD_MESSAGE_TYPING intent in that the bot will receive typing start events from locations other than guilds.

pub const MESSAGE_CONTENT: Intents

Message content intent.

This intent is privileged. See Discord Docs/Privileged Intents.

This intent allows you to receive the contents of all messages.

pub const GUILD_SCHEDULED_EVENTS: Intents

pub const AUTO_MODERATION_CONFIGURATION: Intents

Auto moderation configuration intent.

Event(s) received:

pub const AUTO_MODERATION_EXECUTION: Intents

Auto moderation execution event.

Event(s) received:

pub const GUILD_MESSAGE_POLLS: Intents

Guild polls intent.

Event(s) received:

pub const DIRECT_MESSAGE_POLLS: Intents

Direct message polls intent.

Event(s) received:

Source

impl Intents

pub const fn empty() -> Intents

Get a flags value with all bits unset.

pub const fn all() -> Intents

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Intents>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Intents

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Intents

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Intents>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Intents) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Intents) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Intents)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Intents)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Intents)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Intents, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Intents) -> Intents

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Intents) -> Intents

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Intents) -> Intents

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Intents) -> Intents

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Intents

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl Intents

pub const fn iter(&self) -> Iter<Intents>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Intents>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.